from third_sdk.jd.api.base import RestApi

class OpenBlueInvoiceUploadRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.orderId = None
			self.invoiceCode = None
			self.invoiceNo = None
			self.invoiceTitle = None
			self.invoiceAmount = None
			self.invoiceDate = None
			self.invoiceImgBase64 = None

		def getapiname(self):
			return 'jingdong.open.blueInvoiceUpload'

			








from third_sdk.jd.api.rest.UnionOpenGoodsQueryRequest import UnionOpenGoodsQueryRequest
from third_sdk.jd.api.base import RestApi
from third_sdk.jd import appinfo

class JdClient:

    def __init__(self, host='https://api.jd.com/routerjson', port=80, appkey='', secret='', timeout=30):
        self.__host = host
        self.__port = port
        self.__appkey = appkey
        self.__secret = secret
        self.__timeout = timeout

    def jd_union_open_goods_query(self, req: UnionOpenGoodsQueryRequest = None, access_token=None,
                                  **kwargs):
        if req is None:
            req = UnionOpenGoodsQueryRequest(self.__host, self.__port)
        return self.api_invoke(req, access_token, **kwargs)

    def api_invoke(self, req: RestApi, access_token=None, **kwargs):
        assert req is not None
        req.set_app_info(appinfo(self.__appkey, self.__secret))
        for k, v in kwargs.items():
            setattr(req, k, v)
        return req.getResponse(access_token=access_token, timeout=self.__timeout)



from third_sdk.jd.api.base import RestApi

class UnionOpenGoodsMaterialQueryRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.goodsReq = None

		def getapiname(self):
			return 'jd.union.open.goods.material.query'

		def get_version(self):
			return '1.0'
			
	

class GoodsReq(object):
		def __init__(self):
			"""
			"""
			self.eliteId = None
			self.pageIndex = None
			self.pageSize = None
			self.sortName = None
			self.sort = None
			self.pid = None
			self.subUnionId = None
			self.siteId = None
			self.positionId = None
			self.ext1 = None
			self.skuId = None
			self.hasCoupon = None
			self.userIdType = None
			self.userId = None
			self.fields = None
			self.forbidTypes = None
			self.orderId = None
			self.groupId = None
			self.ownerUnionId = None
			self.benefitType = None








from third_sdk.jd.api.base import RestApi

class KplOpenWfpJmiwareEditWareRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.interfaceName = None
			self.methodName = None
			self.param = None

		def getapiname(self):
			return 'jd.kpl.open.wfp.jmiware.editWare'

		def get_version(self):
			return '1.0'
			
	

class JmiWareImageParam(object):
		def __init__(self):
			"""
			"""
			self.wareId = None
			self.imgPath = None
			self.zone = None
			self.indexId = None


class AttrValue(object):
		def __init__(self):
			"""
			"""
			self.valueObj = None
			self.aliasName = None


class AttrParam(object):
		def __init__(self):
			"""
			"""
			self.letter = None
			self.attrValue = None


class JmiSkuPriceParam(object):
		def __init__(self):
			"""
			"""
			self.jSkuId = None
			self.dateDay = None
			self.stock = None
			self.price = None
			self.settingList = None
			self.extPropertyList = None
			self.preStock = None


class JmiWareSkuParam(object):
		def __init__(self):
			"""
			"""
			self.jSkuId = None
			self.jWareId = None
			self.outerId = None
			self.skuPrice = None
			self.quantity = None
			self.indexOuterId = None
			self.saleList = None
			self.extSetting = None
			self.preStock = None
			self.mainVideoId = None
			self.infoVideoId = None
			self.mainVideoUrl = None
			self.infoVideoUrl = None
			self.jmiSkuPrices = None


class JmiWareParam(object):
		def __init__(self):
			"""
			"""
			self.opName = None
			self.opIp = None
			self.sourceId = None
			self.uuid = None
			self.port = None
			self.jWareId = None
			self.catId = None
			self.venderId = None
			self.shopId = None
			self.title = None
			self.subTitle = None
			self.marketPrice = None
			self.price = None
			self.outerId = None
			self.quantity = None
			self.logo = None
			self.operateType = None
			self.note = None
			self.wareImages = None
			self.features = None
			self.url = None
			self.urlWord = None
			self.onlineTime = None
			self.offlineTime = None
			self.appNote = None
			self.shopCategory = None
			self.wareSettingList = None
			self.categorySettingList = None
			self.skus = None








from third_sdk.jd.api.base import RestApi

class KplOpenAlphaGetconfigurewithloginRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.baseInfo = None

		def getapiname(self):
			return 'jd.kpl.open.alpha.getconfigurewithlogin'

		def get_version(self):
			return '1.0'
			
	

class BaseInfo(object):
		def __init__(self):
			"""
			"""
			self.app_key = None
			self.pin_key = None
			self.device_id = None
			self.mac_address = None
			self.sn = None
			self.version = None
			self.os_type = None
			self.app_version = None
			self.timestamp = None
			self.skill = None
			self.command = None
			self.source_type = None
			self.extend = None
			self.client_ip = None








from third_sdk.jd.api.base import RestApi

class WareProductsortGetRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.product_sort_ids = None

		def getapiname(self):
			return 'jingdong.ware.productsort.get'

			








'''
Created by auto_sdk on 2019.07.04
'''
from third_sdk.top.api.base import RestApi
class TbkUatmFavoritesItemGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.adzone_id = None
		self.favorites_id = None
		self.fields = None
		self.page_no = None
		self.page_size = None
		self.platform = None
		self.unid = None

	def getapiname(self):
		return 'taobao.tbk.uatm.favorites.item.get'



'''
Created by auto_sdk on 2019.07.12
'''
from third_sdk.top.api.base import RestApi
class TbkDgVegasTljCreateRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.adzone_id = None
		self.campaign_type = None
		self.item_id = None
		self.name = None
		self.per_face = None
		self.security_switch = None
		self.send_end_time = None
		self.send_start_time = None
		self.total_num = None
		self.use_end_time = None
		self.use_end_time_mode = None
		self.use_start_time = None
		self.user_total_win_num_limit = None

	def getapiname(self):
		return 'taobao.tbk.dg.vegas.tlj.create'



from third_sdk.jd.api.base import RestApi

class KeplerSettledAftermarketSaveaftermarketRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.afsApplyDto = None
			self.client = None

		def getapiname(self):
			return 'jd.kepler.settled.aftermarket.saveaftermarket'

		def get_version(self):
			return '1.0'
			
	

class CustomerDto(object):
		def __init__(self):
			"""
			"""
			self.customerPin = None
			self.customerName = None
			self.customerContactName = None
			self.customerTel = None
			self.customerMobilePhone = None
			self.customerEmail = None
			self.customerPostcode = None
			self.customerGrade = None


class PickwareDto(object):
		def __init__(self):
			"""
			"""
			self.pickwareType = None
			self.pickwareProvince = None
			self.pickwareCity = None
			self.pickwareCounty = None
			self.pickwareVillage = None
			self.doorPickReserveType = None
			self.pickwareAddress = None
			self.reserveDateStr = None
			self.reserveDateBegin = None
			self.reserveDateEnd = None


class ReturnwareDto(object):
		def __init__(self):
			"""
			"""
			self.returnwareType = None
			self.returnwareProvince = None
			self.returnwareCity = None
			self.returnwareCounty = None
			self.returnwareVillage = None
			self.returnwareAddress = None


class RefundDto(object):
		def __init__(self):
			"""
			"""
			self.bankCode = None
			self.bankName = None
			self.bankProvince = None
			self.bankCity = None
			self.branchBankAddress = None
			self.bankAccountHolder = None
			self.refundType = None


class AfsApplyDetailDto(object):
		def __init__(self):
			"""
			"""
			self.wareName = None
			self.wareBrand = None
			self.wareDescribe = None
			self.wareId = None
			self.wareNum = None
			self.afsDetailType = None
			self.payPrice = None
			self.expandTag = None


class AfsApplyDto(object):
		def __init__(self):
			"""
			"""
			self.platformSrc = None
			self.orderId = None
			self.orderType = None
			self.customerExpect = None
			self.changeSku = None
			self.questionTypeCid1 = None
			self.questionTypeCid2 = None
			self.questionDesc = None
			self.isNeedDetectionReport = None
			self.questionPic = None
			self.isHasPackage = None
			self.packageDesc = None
			self.createName = None
			self.isHasInvoice = None
			self.invoiceCode = None
			self.invoiceTime = None
			self.customerDto = None
			self.pickwareDto = None
			self.returnwareDto = None
			self.refundDto = None
			self.afsApplyDetailDtos = None
			self.applyIdYhd = None


class Client(object):
		def __init__(self):
			"""
			"""
			self.uid = None
			self.userIp = None








import hmac
import json
import time
import requests
from urllib.parse import urlencode


class VipClient:

    __base_params_name = ['appKey', 'format', 'method', 'service', 'timestamp', 'version']

    __default_headers = {
        "contentType": "application/json"
    }

    def __init__(self, host='https://vop.vipapis.com', appkey='', secret='', timeout=30):
        self.__host = host
        self.__appKey = appkey
        self.__appSecret = secret
        self.__timeout = timeout

    def __get_system_params(self, service='com.vip.adp.api.open.service.UnionGoodsService', version='1.0.0', method='',format='json'):
        """
         获取系统参数
        """
        return {
            'service': service,
            'version': version,
            'method': method,
            'timestamp': int(time.time()),
            'format': format,
            'appKey': self.__appKey
        }

    def get_by_goods_ids_v2(self, **kwargs):
        """
        获取商品详情查询接口
        """
        return self.api_invoke(method='getByGoodsIdsV2', **kwargs)


    def api_invoke(self, method='', **kwargs):
        """
        Api 调用通用方法
        """
        params = self.__get_system_params(method=method)
        req_str = ''
        for key in self.__base_params_name:
            req_str += key + str(params[key])
        req_str += json.dumps(kwargs, ensure_ascii=False)
        m = hmac.new(self.__appSecret.encode(), req_str.encode())
        params['sign'] = m.hexdigest().upper()
        return requests.post(f'{self.__host}?{urlencode(params)}', headers=self.__default_headers, json=kwargs, timeout=self.__timeout)








from third_sdk.jd.api.base import RestApi

class KplOpenWeiboCartAddRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.xid = None
			self.url = None
			self.skuId = None
			self.ip = None
			self.appname = None
			self.timestamp = None
			self.deviceid = None
			self.token = None
			self.sessionid = None
			self.signature = None
			self.applicationname = None
			self.packagename = None
			self.applicationmd5 = None
			self.ua = None
			self.os = None
			self.osversion = None

		def getapiname(self):
			return 'jd.kpl.open.weibo.cart.add'

		def get_version(self):
			return '1.0'
			
	







from third_sdk.jd.api.base import RestApi

class KeplerTradeSubmitRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.cartReq = None
			self.orderParam = None

		def getapiname(self):
			return 'jd.kepler.trade.submit'

		def get_version(self):
			return '1.0'
			
	

class User(object):
		def __init__(self):
			"""
			"""
			self.pin = None
			self.level = None
			self.flagInfo = None


class GiftSkuReq(object):
		def __init__(self):
			"""
			"""
			self.sku = None
			self.num = None


class SkuExtentionReq(object):
		def __init__(self):
			"""
			"""
			self.thirdCategoryId = None
			self.vendor = None
			self.vendorType = None


class SkuReq(object):
		def __init__(self):
			"""
			"""
			self.sku = None
			self.num = None
			self.name = None
			self.tagList = None
			self.selectedPromoIdList = None
			self.thirdCategoryId = None
			self.vendor = None
			self.vendorType = None
			self.giftSkuRequestList = None
			self.skuExtentionReq = None


class SuitMainSkuReq(object):
		def __init__(self):
			"""
			"""
			self.sku = None
			self.num = None
			self.thirdCategoryId = None
			self.vendor = None
			self.vendorType = None
			self.tagList = None
			self.selectedPromoIdList = None
			self.giftSkuRequestList = None


class SuitReq(object):
		def __init__(self):
			"""
			"""
			self.promotionId = None
			self.num = None
			self.skuList = None
			self.vskuId = None
			self.virtualSuitType = None


class SelectedPromotionGiftsReq(object):
		def __init__(self):
			"""
			"""
			self.promotionId = None
			self.promotionType = None
			self.giftSkuReqList = None


class CartReq(object):
		def __init__(self):
			"""
			"""
			self.ip = None
			self.areaId = None
			self.user = None
			self.skuList = None
			self.suitList = None
			self.giftList = None
			self.selectedPromotionGiftsReqList = None


class OrderUnionParam(object):
		def __init__(self):
			"""
			"""
			self.unpl = None
			self.unionId = None
			self.unionSiteId = None
			self.unionUserName = None
			self.unionTime = None
			self.unionEx = None
			self.mt_xid = None
			self.mt_subsite = None
			self.mt_ext = None
			self.dmpjs = None


class Address(object):
		def __init__(self):
			"""
			"""
			self.addressId = None
			self.addressType = None
			self.name = None
			self.provinceId = None
			self.cityId = None
			self.countyId = None
			self.townId = None
			self.provinceName = None
			self.cityName = None
			self.countyName = None
			self.townName = None
			self.addressDetail = None
			self.postCode = None
			self.mobile = None
			self.phone = None
			self.email = None
			self.orgId = None
			self.longitude = None
			self.latitude = None
			self.coord_type = None
			self.addressDefault = None
			self.addressName = None
			self.paymentId = None
			self.pickId = None
			self.pickName = None


class CombinationPayment(object):
		def __init__(self):
			"""
			"""
			self.mainPaymentType = None
			self.subPaymentType = None


class InvoiceConsignee(object):
		def __init__(self):
			"""
			"""
			self.consigneeName = None
			self.provinceId = None
			self.province = None
			self.cityId = None
			self.city = None
			self.countyId = None
			self.county = None
			self.townId = None
			self.town = None
			self.phone = None
			self.address = None


class VatInvoice(object):
		def __init__(self):
			"""
			"""
			self.companyName = None
			self.code = None
			self.regAddr = None
			self.regPhone = None
			self.regBank = None
			self.regBankAccount = None
			self.normalInvoiceContent = None
			self.bookInvoiceContent = None
			self.invoiceConsignee = None


class NormalInvoice(object):
		def __init__(self):
			"""
			"""
			self.selectedInvoiceTitle = None
			self.companyName = None
			self.normalInvoiceContent = None
			self.bookInvoiceContent = None
			self.invoiceConsignee = None
			self.code = None


class ElectroInvoice(object):
		def __init__(self):
			"""
			"""
			self.selectInvoiceTitle = None
			self.selectBookInvoiceContent = None
			self.selectNormalInvoiceContent = None
			self.invoiceConsigneeEmail = None
			self.invoiceConsigneePhone = None
			self.compayName = None
			self.code = None


class Invoice(object):
		def __init__(self):
			"""
			"""
			self.selectInvoiceType = None
			self.invoicePutType = None
			self.vatInvoice = None
			self.normalInvoice = None
			self.electroInvoice = None


class GeneralFreight(object):
		def __init__(self):
			"""
			"""
			self.freight = None
			self.verderId = None


class RemoteRegionFreightParam(object):
		def __init__(self):
			"""
			"""
			self.skuId = None
			self.num = None
			self.freight = None
			self.venderId = None


class Freight(object):
		def __init__(self):
			"""
			"""
			self.generalFreight = None
			self.remoteRegionFreightList = None


class ClientInfo(object):
		def __init__(self):
			"""
			"""
			self.serverName = None
			self.userIP = None
			self.countKey = None
			self.netBuySourceType = None
			self.invokeInvoiceBasicService = None
			self.originId = None


class OrderFrom(object):
		def __init__(self):
			"""
			"""
			self.webOriginId = None
			self.flowId = None
			self.siteId = None
			self.originId = None
			self.easybuy = None
			self.locBuy = None
			self.giftbuy = None
			self.lipinkaPhysical = None
			self.contractMachine = None
			self.whiteBar = None
			self.resetDefaultAddress = None
			self.resetResevsion = None
			self.flowType = None
			self.factoryShopId = None
			self.factoryRegionId = None
			self.presale = None
			self.invokeNewCouponInterface = None
			self.resetFlag = None


class OrderParam(object):
		def __init__(self):
			"""
			"""
			self.orderUnionParam = None
			self.payPassword = None
			self.checkcodeTxt = None
			self.checkCodeAnswer = None
			self.trackID = None
			self.userAgent = None
			self.remark = None
			self.sopNotPutInvoice = None
			self.presaleMobile = None
			self.presalePayType = None
			self.giftBuyHidePrice = None
			self.checkCodeRid = None
			self.paymentId = None
			self.orderGuid = None
			self.address = None
			self.combinationPayment = None
			self.invoice = None
			self.freight = None
			self.orderNeedMoney = None
			self.orderNeedMoneyStr = None
			self.clientInfo = None
			self.orderFrom = None
			self.clientPin = None
			self.serverName = None
			self.userIP = None
			self.countKey = None
			self.userKey = None
			self.requestPath = None
			self.repAbsPathPrex = None
			self.fullName = None
			self.gendan = None








from third_sdk.jd.api.base import RestApi

class InvoiceSubmitRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.supplierOrder = None
			self.markId = None
			self.settlementId = None
			self.settlementNum = None
			self.settlementNakedPrice = None
			self.settlementTaxPrice = None
			self.invoiceType = None
			self.invoiceOrg = None
			self.bizInvoiceContent = None
			self.invoiceDate = None
			self.title = None
			self.billToParty = None
			self.enterpriseTaxpayer = None
			self.billToer = None
			self.billToContact = None
			self.billToProvince = None
			self.billToCity = None
			self.billToCounty = None
			self.billToTown = None
			self.billToAddress = None
			self.repaymentDate = None
			self.invoiceNum = None
			self.invoiceNakedPrice = None
			self.invoiceTaxPrice = None
			self.currentBatch = None
			self.totalBatch = None
			self.totalBatchInvoiceNakedAmount = None
			self.totalBatchInvoiceTaxAmount = None
			self.totalBatchInvoiceAmount = None
			self.billingType = None
			self.invoicePrice = None
			self.isMerge = None
			self.poNo = None
			self.enterpriseRegAddress = None
			self.enterpriseRegPhone = None
			self.enterpriseBankName = None
			self.enterpriseBankAccount = None

		def getapiname(self):
			return 'biz.invoice.submit'

		def get_version(self):
			return '1.0'
			
	







'''
Created by auto_sdk on 2019.07.04
'''
from third_sdk.top.api.base import RestApi
class TbkContentGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.adzone_id = None
		self.before_timestamp = None
		self.cid = None
		self.content_set = None
		self.count = None
		self.image_height = None
		self.image_width = None
		self.type = None

	def getapiname(self):
		return 'taobao.tbk.content.get'



from third_sdk.jd.api.base import RestApi

class KplOpenYaoMultipriceUpdateRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.venderId = None
			self.list = None

		def getapiname(self):
			return 'jd.kpl.open.yao.multiprice.update'

		def get_version(self):
			return '1.0'
			
	

class PriceName(object):
		def __init__(self):
			"""
			"""
			self.price = None
			self.priceNameEnum = None


class ListVo(object):
		def __init__(self):
			"""
			"""
			self.venderSku = None
			self.priceNames = None








from third_sdk.jd.api.base import RestApi

class KeplerXuanpinSearchSkuRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.queryParam = None
			self.pageParam = None
			self.orderField = None

		def getapiname(self):
			return 'jd.kepler.xuanpin.search.sku'

		def get_version(self):
			return '1.0'
			
	

class QueryParam(object):
		def __init__(self):
			"""
			"""
			self.keywords = None
			self.cids1 = None
			self.cids2 = None
			self.cids3 = None
			self.sellerType = None
			self.minPrice = None
			self.maxPrice = None


class PageParam(object):
		def __init__(self):
			"""
			"""
			self.pageNum = None
			self.pageSize = None








from third_sdk.jd.api.base import RestApi

class KplOpenItemFindcanusecouponsRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.uid = None
			self.cid = None
			self.sku = None

		def getapiname(self):
			return 'jd.kpl.open.item.findcanusecoupons'

		def get_version(self):
			return '1.0'
			
	







'''
Created by auto_sdk on 2019.09.11
'''
from third_sdk.top.api.base import RestApi
class TbkDgVegasTljInstanceReportRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.rights_id = None

	def getapiname(self):
		return 'taobao.tbk.dg.vegas.tlj.instance.report'



from third_sdk.jd.api.base import RestApi

class SearchWareRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.key = None
			self.filt_type = None
			self.area_ids = None
			self.sort_type = None
			self.page = None
			self.charset = None
			self.urlencode = None

		def getapiname(self):
			return 'jingdong.search.ware'

			








from third_sdk.jd.api.base import RestApi

class KplOpenRankInfoGatherServiceRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.clientParam = None
			self.rankParam = None

		def getapiname(self):
			return 'jingdong.kpl.open.RankInfoGatherService'

			
	

class ClientParam(object):
		def __init__(self):
			"""
			"""
			self.channel = None
			self.source = None


class RankParam(object):
		def __init__(self):
			"""
			"""
			self.rankType = None
			self.ids = None
			self.params = None








from third_sdk.jd.api.base import RestApi

class KplOpenOrderInfoQueryorderRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.var1 = None

		def getapiname(self):
			return 'jd.kpl.open.order.info.queryorder'

		def get_version(self):
			return '1.0'
			
	

class Var1(object):
		def __init__(self):
			"""
			"""
			self.unionId = None
			self.childUnionId = None
			self.optType = None
			self.time = None
			self.pageNo = None
			self.pageSize = None








from third_sdk import top


class TbClient:

    def __init__(self, host='http://gw.api.taobao.com/router/rest', port=80, appkey='', secret='', timeout=30):
        self.__host = host
        self.__port = port
        self.__appkey = appkey
        self.__secret = secret
        self.__timeout = timeout

    def taobao_tbk_dg_material_optional(self, req: top.api.TbkDgMaterialOptionalRequest = None, access_token=None, **kwargs):
        """
        物料搜索
        """
        if req is None:
            req = top.api.TbkDgMaterialOptionalRequest(self.__host, self.__port)
        return self.api_invoke(req, access_token, **kwargs)

    def taobao_tbk_dg_item_info_get(self, req: top.api.TbkItemInfoGetRequest = None, access_token=None, **kwargs):
        """
        商品详情查询(简版)
        """
        if req is None:
            req = top.api.TbkItemInfoGetRequest(self.__host, self.__port)
        return self.api_invoke(req, access_token, **kwargs)

    def api_invoke(self, req: top.api.base.RestApi, access_token=None, **kwargs):
        """
        api 调用通用方法
        """
        assert req is not None
        req.set_app_info(top.appinfo(self.__appkey, self.__secret))
        for k, v in kwargs.items():
            setattr(req, k, v)
        return req.getResponse(authrize=access_token, timeout=self.__timeout)


from third_sdk.jd.api.base import RestApi

class UnionOpenGoodsQueryRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.goodsReqDTO = None

		def getapiname(self):
			return 'jd.union.open.goods.query'

		def get_version(self):
			return '1.0'
			
	

class GoodsReqDTO(object):
		def __init__(self):
			"""
			"""
			self.cid1 = None
			self.cid2 = None
			self.cid3 = None
			self.pageIndex = None
			self.pageSize = None
			self.skuIds = None
			self.keyword = None
			self.pricefrom = None
			self.priceto = None
			self.commissionShareStart = None
			self.commissionShareEnd = None
			self.owner = None
			self.sortName = None
			self.sort = None
			self.isCoupon = None
			self.isPG = None
			self.pingouPriceStart = None
			self.pingouPriceEnd = None
			self.isHot = None
			self.brandCode = None
			self.shopId = None
			self.hasContent = None
			self.hasBestCoupon = None
			self.pid = None
			self.fields = None
			self.forbidTypes = None
			self.jxFlags = None
			self.shopLevelFrom = None
			self.isbn = None
			self.spuId = None
			self.couponUrl = None
			self.deliveryType = None
			self.eliteType = None
			self.isSeckill = None
			self.isPresale = None
			self.isReserve = None








from third_sdk.jd.api.base import RestApi

class UnionOpenUserPidGetRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.pidReq = None

		def getapiname(self):
			return 'jd.union.open.user.pid.get'

		def get_version(self):
			return '1.0'
			
	

class PidReq(object):
		def __init__(self):
			"""
			"""
			self.unionId = None
			self.childUnionId = None
			self.promotionType = None
			self.positionName = None
			self.mediaName = None








try:
    from setuptools import setup
except:
    from distutils.core import setup
import setuptools

setup(
    name='cps_sdk',
    author='dragons',
    version='0.0.1',
    description='CPS SDK汇总',
    long_description='CPS SDK汇总',
    author_email='521274311@qq.com',
    url='https://gitee.com/kingons/third_sdk',
    packages=setuptools.find_packages(),
    install_requires= [
    ],
    classifiers=[
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3.7',
        'Topic :: Software Development :: Libraries',
    ],
    zip_safe=True,
)


'''
Created by auto_sdk on 2019.07.04
'''
from third_sdk.top.api.base import RestApi
class TbkShopGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.end_auction_count = None
		self.end_commission_rate = None
		self.end_credit = None
		self.end_total_action = None
		self.fields = None
		self.is_tmall = None
		self.page_no = None
		self.page_size = None
		self.platform = None
		self.q = None
		self.sort = None
		self.start_auction_count = None
		self.start_commission_rate = None
		self.start_credit = None
		self.start_total_action = None

	def getapiname(self):
		return 'taobao.tbk.shop.get'
